NumLPA package documentation
============================

Welcome!
This documentation has been carefully prepared to allow you to start using the package quickly and to understand its configuration possibilities.
The first section is dedicated to the discovery and use of the package while the second one documents the code.
Hopefully you will find the information you are looking for!

.. toctree::
   :maxdepth: 2
   :caption: Contents:
   :glob:

   practice
   auto/numlpa

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
